# encoding: utf-8
"""
pyparadopp package for reading Nortek Paradopp binary files
===========================================================

Classes

    ParadoppFile -- Base class to access Paradopp binary files.
    
    ParadoppDataStruct -- Base class for data structures.
    
    HWConfig -- Hardware configuration class.
    HeadConfig -- Head configuration class.
    UserConfig -- User configuration class.
    
    HRAquadoppProfileData -- HR Aquaddopp profilier data class.
    
    DataCollection -- Class to collect data from Paradopp structure classes
        into a single class and set of data for optimization.
    
    Methods
        convert_dates -- Converts potential datetime objects to Matlab datenum.
        checksum_test -- Test if checksums match the data.
        walk_dict -- Recursively walks a dictionary, apply a function.
        strip_null -- Strips null characters from end of string.
        bcddate2python -- Convert BCD style dates to datetime objects.
        bcd2dec -- Convert Binary Coded Decimal (BCD) to Decimal.
    
    Exceptions
    
    Error -- Base error class.
    ChecksumError -- Exception raised for mismatched checksums.
    SyncError -- Exception raised for mismatched sync bytes.


"""

from .utils import *
from .structs import *
from .base import *
from .files import *
