# encoding: utf-8
"""
Python classes for Paradopp binary data structures
==================================================

    Classes
    
        ParadoppDataStruct -- Base class for data structures.
        
        HWConfig -- Hardware configuration class.
        HeadConfig -- Head configuration class.
        UserConfig -- User configuration class.
        
        HRAquadoppProfileData -- HR Aquaddopp profilier data class.
        
    
    Subpackage containing modules and classes for interpreting the Paradopp 
    binary data structure formats.  The main base class is ParadoppDataStruct.  
    All valid data structure class are subclasses of this class.  See 
    ParadoppDataStruct for information on the methods and attributes each 
    subclass should define.
"""


__all__ = ['ParadoppDataStruct', 'HWConfig', 'HeadConfig', 'UserConfig']
__all__ += ['HRAquadoppProfileData']
__all__ += ['VectorHeader', 'VectorVelocityData', 'VectorSystemData',
           'VectorProbeCheck']


from common import *
from aquadopp import *
from vector import *